@@ -5,8 +5,8 @@
  */
 
 #include "formlayoutattached.h"
-#include <QQuickItem>
 #include <QDebug>
+#include <QQuickItem>
 
 FormLayoutAttached::FormLayoutAttached(QObject *parent)
     : QObject(parent)
@@ -25,7 +25,7 @@ void FormLayoutAttached::setLabel(const QString &text)
     }
 
     m_label = text;
-    emit labelChanged();
+    Q_EMIT labelChanged();
 }
 
 QString FormLayoutAttached::label() const
@@ -33,6 +33,21 @@ QString FormLayoutAttached::label() const
     return m_label;
 }
 
+void FormLayoutAttached::setLabelAlignment(int alignment)
+{
+    if (m_labelAlignment == alignment) {
+        return;
+    }
+
+    m_labelAlignment = alignment;
+    Q_EMIT labelAlignmentChanged();
+}
+
+int FormLayoutAttached::labelAlignment() const
+{
+    return m_labelAlignment;
+}
+
 void FormLayoutAttached::setIsSection(bool section)
 {
     if (m_isSection == section) {
@@ -40,7 +55,7 @@ void FormLayoutAttached::setIsSection(bool section)
     }
 
     m_isSection = section;
-    emit isSectionChanged();
+    Q_EMIT isSectionChanged();
 }
 
 bool FormLayoutAttached::isSection() const
@@ -55,7 +70,7 @@ void FormLayoutAttached::setCheckable(bool checkable)
     }
 
     m_checkable = checkable;
-    emit checkableChanged();
+    Q_EMIT checkableChanged();
 }
 
 bool FormLayoutAttached::checkable() const
@@ -70,7 +85,7 @@ void FormLayoutAttached::setChecked(bool checked)
     }
 
     m_checked = checked;
-    emit checkedChanged();
+    Q_EMIT checkedChanged();
 }
 
 bool FormLayoutAttached::checked() const
@@ -85,7 +100,7 @@ void FormLayoutAttached::setEnabled(bool enabled)
     }
 
     m_enabled = enabled;
-    emit enabledChanged();
+    Q_EMIT enabledChanged();
 }
 
 bool FormLayoutAttached::enabled() const
@@ -105,7 +120,7 @@ void FormLayoutAttached::setBuddyFor(QQuickItem *buddyfor)
     }
 
     m_buddyFor = buddyfor;
-    emit buddyForChanged();
+    Q_EMIT buddyForChanged();
 }
 
 FormLayoutAttached *FormLayoutAttached::qmlAttachedProperties(QObject *object)
